@@ -9,6 +9,11 @@ ANCHOR_NAMES = dict(sw='start',
                     se='end')
 
 
+class DummyWindow:
+    def call(self, *args, **kwargs):
+        pass
+
+
 class Canvas(object):
     def __init__(self, width=400, height=250):
         self.options = {'width': width,
@@ -69,9 +74,13 @@ class Canvas(object):
             return
         if item_details.attribs.get('image') == '':
             return
-        xoff = self.winfo_width() / 2 + 0.5
-        yoff = self.winfo_height() / 2 + 0.5
+        sx1, sy1, sx2, sy2 = self.options.get(
+            'scrollregion',
+            (0, -self.winfo_height(), self.winfo_width(), 0))
+        xoff = 0.5 - sx1
+        yoff = 0.5 - sy1
         coords = list(item_details.coords)
+        # noinspection DuplicatedCode
         for i in range(0, len(coords), 2):
             x, y = coords[i:i+2]
             x = x + xoff
@@ -125,6 +134,9 @@ class Canvas(object):
     def config(self, **kwargs):
         self.options.update(kwargs)
 
+    def find_all(self):
+        return range(len(self.items))
+
     def coords(self, item, *coords):
         item_details = self.items[item]
         if len(coords) == 0:
@@ -142,6 +154,10 @@ class Canvas(object):
             item_details = self.items[item]
             item_details.is_deleted = True
 
+    @staticmethod
+    def winfo_toplevel():
+        return DummyWindow()
+
     def update(self):
         pass
 
